#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prettyprinter-compat-ansi-wl-pprint
version:              1.0.2
visibility:           public
id:
    prettyprinter-compat-ansi-wl-pprint-1.0.2-KylhGvt3YKb1kUxGBdzOQ2

key:
    prettyprinter-compat-ansi-wl-pprint-1.0.2-KylhGvt3YKb1kUxGBdzOQ2

license:              BSD-2-Clause
maintainer:           David Luposchainsky <dluposchainsky at google>
author:               David Luposchainsky
homepage:             http://github.com/quchen/prettyprinter
synopsis:
    Drop-in compatibility package to migrate from »ansi-wl-pprint« to »prettyprinter«.

description:          See README.md
category:             User Interfaces, Text
abi:                  070352054a3be5ce630b8905c7a41c8e
exposed:              True
exposed-modules:      Text.PrettyPrint.ANSI.Leijen
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/prettyprinter-compat-ansi-wl-pprint-1.0.2

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/prettyprinter-compat-ansi-wl-pprint-1.0.2

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/prettyprinter-compat-ansi-wl-pprint-1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter-compat-ansi-wl-pprint
hs-libraries:
    HSprettyprinter-compat-ansi-wl-pprint-1.0.2-KylhGvt3YKb1kUxGBdzOQ2

depends:
    base-4.18.2.1 prettyprinter-1.7.1-GYMoZhm5WQBJ0L449u3Swb
    prettyprinter-ansi-terminal-1.1.4-2ZsO9RQWyxKCDZAB0kK5ra text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-compat-ansi-wl-pprint/html/prettyprinter-compat-ansi-wl-pprint.haddock

haddock-html:
    /usr/share/doc/haskell-prettyprinter-compat-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

